// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"leit.com/aps_engine/grmi"
	"xorm.io/core"
)

type DayModel struct {
	PlantNr         int           `xorm:"pk int 'PlantNr'" json:"DayModel-PlantNr"`
	DayModelNr      int           `xorm:"pk int 'DayModelNr' autoincr" json:"DayModel-DayModelNr"`
	Descr           string        `xorm:"nvarchar(100) 'Descr'" json:"DayModel-Descr"`
	Abrev           string        `xorm:"nvarchar(10) 'Abrev' not null" json:"DayModel-Abrev"`
	HexColor        string        `xorm:"nvarchar(10) 'HexColor'" json:"DayModel-HexColor"`
	S1Toggle        bool          `xorm:"bit 'S1Toggle' not null" json:"DayModel-S1Toggle"`
	S2Toggle        bool          `xorm:"bit 'S2Toggle' not null" json:"DayModel-S2Toggle"`
	S3Toggle        bool          `xorm:"bit 'S3Toggle' not null" json:"DayModel-S3Toggle"`
	WorkShiftToggle bool          `xorm:"bit 'WorkShiftToggle' not null" json:"DayModel-WorkShiftToggle"`
	S1WorkShiftNr   int           `xorm:"int 'S1_WorkShiftNr' not null" json:"DayModel-S1_WorkShiftNr"`
	S2WorkShiftNr   int           `xorm:"int 'S2_WorkShiftNr' not null" json:"DayModel-S2_WorkShiftNr"`
	S3WorkShiftNr   int           `xorm:"int 'S3_WorkShiftNr' not null" json:"DayModel-S3_WorkShiftNr"`
	S1Beg           int           `xorm:"int 'S1_Beg'" json:"DayModel-S1_Beg"`
	S1End           int           `xorm:"int 'S1_End'" json:"DayModel-S1_End"`
	S1Len           int           `xorm:"int 'S1_Len'" json:"DayModel-S1_Len"`
	S2Beg           int           `xorm:"int 'S2_Beg'" json:"DayModel-S2_Beg"`
	S2End           int           `xorm:"int 'S2_End'" json:"DayModel-S2_End"`
	S2Len           int           `xorm:"int 'S2_Len'" json:"DayModel-S2_Len"`
	S3Beg           int           `xorm:"int 'S3_Beg'" json:"DayModel-S3_Beg"`
	S3End           int           `xorm:"int 'S3_End'" json:"DayModel-S3_End"`
	S3Len           int           `xorm:"int 'S3_Len'" json:"DayModel-S3_Len"`
	DmLen           int           `xorm:"int 'Dm_Len'" json:"DayModel-Dm_Len"`
	S1B1Beg         int           `xorm:"int 'S1_B1_Beg'" json:"DayModel-S1_B1_Beg"`
	S1B1End         int           `xorm:"int 'S1_B1_End'" json:"DayModel-S1_B1_End"`
	S1B2Beg         int           `xorm:"int 'S1_B2_Beg'" json:"DayModel-S1_B2_Beg"`
	S1B2End         int           `xorm:"int 'S1_B2_End'" json:"DayModel-S1_B2_End"`
	S1B3Beg         int           `xorm:"int 'S1_B3_Beg'" json:"DayModel-S1_B3_Beg"`
	S1B3End         int           `xorm:"int 'S1_B3_End'" json:"DayModel-S1_B3_End"`
	S1B4Beg         int           `xorm:"int 'S1_B4_Beg'" json:"DayModel-S1_B4_Beg"`
	S1B4End         int           `xorm:"int 'S1_B4_End'" json:"DayModel-S1_B4_End"`
	S1B5Beg         int           `xorm:"int 'S1_B5_Beg'" json:"DayModel-S1_B5_Beg"`
	S1B5End         int           `xorm:"int 'S1_B5_End'" json:"DayModel-S1_B5_End"`
	S2B1Beg         int           `xorm:"int 'S2_B1_Beg'" json:"DayModel-S2_B1_Beg"`
	S2B1End         int           `xorm:"int 'S2_B1_End'" json:"DayModel-S2_B1_End"`
	S2B2Beg         int           `xorm:"int 'S2_B2_Beg'" json:"DayModel-S2_B2_Beg"`
	S2B2End         int           `xorm:"int 'S2_B2_End'" json:"DayModel-S2_B2_End"`
	S2B3Beg         int           `xorm:"int 'S2_B3_Beg'" json:"DayModel-S2_B3_Beg"`
	S2B3End         int           `xorm:"int 'S2_B3_End'" json:"DayModel-S2_B3_End"`
	S2B4Beg         int           `xorm:"int 'S2_B4_Beg'" json:"DayModel-S2_B4_Beg"`
	S2B4End         int           `xorm:"int 'S2_B4_End'" json:"DayModel-S2_B4_End"`
	S2B5Beg         int           `xorm:"int 'S2_B5_Beg'" json:"DayModel-S2_B5_Beg"`
	S2B5End         int           `xorm:"int 'S2_B5_End'" json:"DayModel-S2_B5_End"`
	S3B1Beg         int           `xorm:"int 'S3_B1_Beg'" json:"DayModel-S3_B1_Beg"`
	S3B1End         int           `xorm:"int 'S3_B1_End'" json:"DayModel-S3_B1_End"`
	S3B2Beg         int           `xorm:"int 'S3_B2_Beg'" json:"DayModel-S3_B2_Beg"`
	S3B2End         int           `xorm:"int 'S3_B2_End'" json:"DayModel-S3_B2_End"`
	S3B3Beg         int           `xorm:"int 'S3_B3_Beg'" json:"DayModel-S3_B3_Beg"`
	S3B3End         int           `xorm:"int 'S3_B3_End'" json:"DayModel-S3_B3_End"`
	S3B4Beg         int           `xorm:"int 'S3_B4_Beg'" json:"DayModel-S3_B4_Beg"`
	S3B4End         int           `xorm:"int 'S3_B4_End'" json:"DayModel-S3_B4_End"`
	S3B5Beg         int           `xorm:"int 'S3_B5_Beg'" json:"DayModel-S3_B5_Beg"`
	S3B5End         int           `xorm:"int 'S3_B5_End'" json:"DayModel-S3_B5_End"`
	LastModify      grmi.DateTime `xorm:"datetime 'LastModify' not null updated" json:"DayModel-LastModify"`
	LastUser        string        `xorm:"nvarchar(20) 'LastUser' not null" json:"DayModel-LastUser"`
	CreateTime      grmi.DateTime `xorm:"datetime 'CreateTime' not null created" json:"DayModel-CreateTime"`
}

/******数据表名******/
func (t *DayModel) TableName() string {
	return "DayModel"
}

/******************************************************************************
 *
 * @Function Name            : GetKey
 *-----------------------------------------------------------------------------
 *
 * @Description              : 获取实体的主键
 *
 * @Return Value             : 实体的主键
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 17:06:57
 *
 ******************************************************************************/
func (self *DayModel) GetKey() core.PK {
	return core.PK{self.PlantNr, self.DayModelNr}
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *DayModel) Add() error {
	e := db.Eloquent.Master()
	count := new(DayModel)
	affw, err := e.Table(t.TableName()).ID(t.GetKey()).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *DayModel) Del() bool {
	e := db.Eloquent.Master()
	_, err := e.ID(t.GetKey()).Delete(&DayModel{})
	if err != nil {
		return false
	}
	return true
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *DayModel) Update() error {
	e := db.Eloquent.Master()
	_, err := e.ID(t.GetKey()).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *DayModel) SelectOne() (data DayModel, err error) {
	e := db.Eloquent.Master()
	if _, err = e.ID(t.GetKey()).Get(&data); err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *DayModel) SelectAll() (datalst []DayModel, err error) {
	e := db.Eloquent.Master()
	if err = e.Table(t.TableName()).Where("PlantNr = ?",t.PlantNr).OrderBy("DayModelNr").Find(&datalst); err != nil{
		return
	}
	return
}
