// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type MeProject struct {
	Plantnr                int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Projectid              string    `json:"ProjectId" xorm:"not null pk NVARCHAR(80)"`
	Descr                  string    `json:"Descr" xorm:"not null NVARCHAR(200)"`
	Enabletoggle           int       `json:"EnableToggle" xorm:"not null BIT(1)"`
	Plantsitecode          int       `json:"PlantSiteCode" xorm:"not null INT(4)"`
	Custname1              string    `json:"CustName1" xorm:"not null NVARCHAR(200)"`
	Custname2              string    `json:"CustName2" xorm:"not null NVARCHAR(200)"`
	Fileserverhost         string    `json:"FileServerHost" xorm:"not null NVARCHAR(120)"`
	Filefolder1            string    `json:"FileFolder1" xorm:"not null NVARCHAR(200)"`
	Filefolder2            string    `json:"FileFolder2" xorm:"not null NVARCHAR(200)"`
	Filefolder3            string    `json:"FileFolder3" xorm:"not null NVARCHAR(200)"`
	Filefolder4            string    `json:"FileFolder4" xorm:"not null NVARCHAR(200)"`
	Filefolder5            string    `json:"FileFolder5" xorm:"not null NVARCHAR(200)"`
	Filefolder6            string    `json:"FileFolder6" xorm:"not null NVARCHAR(200)"`
	File1nameregexp        string    `json:"File1NameRegexp" xorm:"not null NVARCHAR(200)"`
	File2nameregexp        string    `json:"File2NameRegexp" xorm:"not null NVARCHAR(200)"`
	File3nameregexp        string    `json:"File3NameRegexp" xorm:"not null NVARCHAR(200)"`
	File4nameregexp        string    `json:"File4NameRegexp" xorm:"not null NVARCHAR(200)"`
	File5nameregexp        string    `json:"File5NameRegexp" xorm:"not null NVARCHAR(200)"`
	File6nameregexp        string    `json:"File6NameRegexp" xorm:"not null NVARCHAR(200)"`
	Orderverifyruletoggle1 int       `json:"OrderVerifyRuleToggle1" xorm:"not null BIT(1)"`
	Orderverifyruletoggle2 int       `json:"OrderVerifyRuleToggle2" xorm:"not null BIT(1)"`
	Orderverifyruletoggle3 int       `json:"OrderVerifyRuleToggle3" xorm:"not null BIT(1)"`
	Orderverifyruletoggle4 int       `json:"OrderVerifyRuleToggle4" xorm:"not null BIT(1)"`
	Orderverifyruletoggle5 int       `json:"OrderVerifyRuleToggle5" xorm:"not null BIT(1)"`
	Orderverifyruletoggle6 int       `json:"OrderVerifyRuleToggle6" xorm:"not null BIT(1)"`
	Orderverifyrule1       string    `json:"OrderVerifyRule1" xorm:"not null NVARCHAR(200)"`
	Orderverifyrule2       string    `json:"OrderVerifyRule2" xorm:"not null NVARCHAR(200)"`
	Orderverifyrule3       string    `json:"OrderVerifyRule3" xorm:"not null NVARCHAR(200)"`
	Orderverifyrule4       string    `json:"OrderVerifyRule4" xorm:"not null NVARCHAR(200)"`
	Orderverifyrule5       string    `json:"OrderVerifyRule5" xorm:"not null NVARCHAR(200)"`
	Orderverifyrule6       string    `json:"OrderVerifyRule6" xorm:"not null NVARCHAR(200)"`
	Emailserverhost        string    `json:"EmailServerHost" xorm:"not null NVARCHAR(120)"`
	Emailserverport        int       `json:"EmailServerPort" xorm:"not null INT(4)"`
	Fromemail              string    `json:"FromEmail" xorm:"not null NVARCHAR(200)"`
	Frompwd                string    `json:"FromPwd" xorm:"not null NVARCHAR(200)"`
	Errorrecievers         string    `json:"ErrorRecievers" xorm:"not null NVARCHAR(200)"`
	Errorccrecievers       string    `json:"ErrorCcRecievers" xorm:"not null NVARCHAR(200)"`
	Logurl                 string    `json:"LogUrl" xorm:"not null NVARCHAR(120)"`
	Logtable               string    `json:"LogTable" xorm:"not null NVARCHAR(80)"`
	Custordersnr           string    `json:"CustOrderSnr" xorm:"not null NVARCHAR(80)"`
	Workordersnr           string    `json:"WorkOrderSnr" xorm:"not null NVARCHAR(80)"`
	Serialordersnr         string    `json:"SerialOrderSnr" xorm:"not null NVARCHAR(80)"`
	Manualordersnr         string    `json:"ManualOrderSnr" xorm:"not null NVARCHAR(80)"`
	Ordermsgsnr            string    `json:"OrderMsgSnr" xorm:"not null NVARCHAR(80)"`
	Reworkordersnr         string    `json:"ReworkOrderSnr" xorm:"not null NVARCHAR(80)"`
	Packordersnr           string    `json:"PackOrderSnr" xorm:"not null NVARCHAR(80)"`
	Packordersyncsnr       string    `json:"PackOrderSyncSnr" xorm:"not null NVARCHAR(80)"`
	Shipordersnr           string    `json:"ShipOrderSnr" xorm:"not null NVARCHAR(80)"`
	Shipfilesnr            string    `json:"ShipFileSnr" xorm:"not null NVARCHAR(80)"`
	Asnfilesnr             string    `json:"AsnFileSnr" xorm:"not null NVARCHAR(80)"`
	Lastmodify             time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser               string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime             time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
}

/******数据表名******/
func (t *MeProject) TableName() string {
	return "MeProject"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *MeProject) Add() error {
	e := db.Eloquent.Master()
	projtab := new(MeProject)
	/**主键：****/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Projectid}).Count(projtab)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *MeProject) Del() error {
	e := db.Eloquent.Master()
	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Projectid}).Delete(&MeProject{})
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *MeProject) Update() error {
	e := db.Eloquent.Master()
	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Projectid}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *MeProject) SelectOne() (MeProject, error) {
	var data MeProject

	e := db.Eloquent.Master()
	_, err := e.ID(core.PK{t.Plantnr, t.Projectid}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *MeProject) SelectActiveProjects() (datalst []MeProject, err error) {
	e := db.Eloquent.Master()
	if err = e.Where("PlantNr = ? and EnableToggle = ?",t.Plantnr, 1).OrderBy("ProjectId").Find(&datalst); err != nil{
		return
	}
	return
}