// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type OmWooperation struct {
	Plantnr                      int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Workorderid                  string    `json:"WorkOrderId" xorm:"not null pk NVARCHAR(80)"`
	Operationnr                  int       `json:"OperationNr" xorm:"not null pk INT(4)"`
	Splitnr                      int       `json:"SplitNr" xorm:"not null pk INT(4)"`
	Descr                        string    `json:"Descr" xorm:"not null NVARCHAR(200)"`
	Standardoperationid          string    `json:"StandardOperationId" xorm:"not null NVARCHAR(80)"`
	Operationtype                string    `json:"OperationType" xorm:"not null NVARCHAR(40)"`
	Workplacegrpnr          	 int       `json:"WorkPlaceGrpNr" xorm:"not null INT(4)"`
	Workplacenr                  int       `json:"WorkPlaceNr" xorm:"not null INT(4)"`
	Usedworkplacenr              int       `json:"UsedWorkPlaceNr" xorm:"not null INT(4)"`
	Setupduration                float32   `json:"SetupDuration" xorm:"not null FLOAT(8)"`
	Afterprocessduration         float32   `json:"AfterProcessDuration" xorm:"not null FLOAT(8)"`
	Durationuomid                string    `json:"DurationUomId" xorm:"not null NVARCHAR(80)"`
	Planstarttime                string    `json:"PlanStartTime" xorm:"not null NVARCHAR(28)"`
	Planendtime                  string    `json:"PlanEndTime" xorm:"not null NVARCHAR(28)"`
	Actstarttime                 string    `json:"ActStartTime" xorm:"not null NVARCHAR(28)"`
	Actendtime                   string    `json:"ActEndTime" xorm:"not null NVARCHAR(28)"`
	Planqty                      float32   `json:"PlanQty" xorm:"not null FLOAT(8)"`
	Planscraprate                float32   `json:"PlanScrapRate" xorm:"not null FLOAT(8)"`
	Rateperhourtoggle            int       `json:"RatePerHourToggle" xorm:"not null BIT(1)"`
	Timeperitemtoggle            int       `json:"TimePerItemToggle" xorm:"not null BIT(1)"`
	Timeperbatchtoggle           int       `json:"TimePerBatchToggle" xorm:"not null BIT(1)"`
	Batchtimefieldtoggle         int       `json:"BatchTimeFieldToggle" xorm:"not null BIT(1)"`
	Optimeperitem                float32   `json:"OpTimePerItem" xorm:"FLOAT(8)"`
	Batchtime                    float32   `json:"BatchTime" xorm:"FLOAT(8)"`
	Quantityperhour              float32   `json:"QuantityPerHour" xorm:"not null FLOAT(8)"`
	Midbatchquantity             int       `json:"MidBatchQuantity" xorm:"not null INT(4)"`
	Midbatchtime                 time.Time `json:"MidBatchTime" xorm:"DATETIME(8)"`
	Effectiveoptime              float32   `json:"EffectiveOpTime" xorm:"FLOAT(8)"`
	Batchingmethod               int       `json:"BatchingMethod" xorm:"not null INT(4)"`
	Transfertoggle               int       `json:"TransferToggle" xorm:"not null BIT(1)"`
	Splittoggle                  int       `json:"SplitToggle" xorm:"not null BIT(1)"`
	Transferquantity             float32   `json:"TransferQuantity" xorm:"not null FLOAT(8)"`
	Lotsize                      float32   `json:"LotSize" xorm:"FLOAT(8)"`
	Maxtimebeforenextop          float32   `json:"MaxTimeBeforeNextOp" xorm:"FLOAT(8)"`
	Maximumoperationspanincrease float32   `json:"MaximumOperationSpanIncrease" xorm:"not null FLOAT(8)"`
	Slacktimeafterlastoperation  float32   `json:"SlackTimeAfterLastOperation" xorm:"FLOAT(8)"`
	Lastmodify                   time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser                     string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime                   time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
	Artlst       				 []OmWooperationartlst 		`xorm:"-"`
	Yieldlst       				 []OmWooperationyieldlst 	`xorm:"-"`
	Skilllst   					 []OmWooperationskilllst	`xorm:"-"`
	Toollst 					 []OmWooperationtoollst		`xorm:"-"`
	Resourcelst 				 []OmWooperationresourcelst	`xorm:"-"`
}

/******数据表名******/
func (t *OmWooperation) TableName() string {
	return "OmWooperation"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperation) Add() error {
	e := db.Eloquent.Master()
	count := new(OmWooperation)
	/**主键：****/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperation) Del() (err error) {
	e := db.Eloquent.Master()
	/**主键：****/
	_, err = e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Delete(&OmWooperation{})
	if err != nil {
		return
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperation) Update() error {
	e := db.Eloquent.Master()
	/**主键：****/
	_, err := e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 查找工序完整数据
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Leo Xue
 *
 * @Date               : 2021/5/10 8:47
 *
 ******************************************************************************/
func (t *OmWooperation) SelectOne() (data OmWooperation, err error) {

	e := db.Eloquent.Master()

	_, err = e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Get(&data)
	if err != nil {
		return data, err
	}

	// 获取工序的关联关系数据

	// 获取工序的物料数据
	if err = e.Table("OmWooperationartlst").Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr).Asc("ArtId").Find(&data.Artlst); err != nil{
		return
	}
	// 获取工序的物料产出数据
	if err = e.Table("OmWooperationyieldlst").Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr).Asc("ArtId").Find(&data.Yieldlst); err != nil{
		return
	}
	// 获取工序的工具数据
	if err = e.Table("OmWooperationtoollst").Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr).Asc("ToolGrpNr").Find(&data.Toollst); err != nil{
		return
	}
	// 获取工序的技能数据
	if err = e.Table("OmWooperationskilllst").Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr).Asc("SkillNr").Find(&data.Toollst); err != nil{
		return
	}
	// 获取工序的第二资源需求数据
	if err = e.Table("OmWooperationresourcelst").Where("PlantNr = ? and WorkOrderId = ? and OperationNr = ? and SplitNr = ?",
		t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr).Asc("ResourceNr").Find(&data.Toollst); err != nil{
		return
	}

	return data, nil
}
