// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type OmWooperationqty struct {
	Plantnr       int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Workorderid   string    `json:"WorkOrderId" xorm:"not null pk NVARCHAR(80)"`
	Operationnr   int       `json:"OperationNr" xorm:"not null pk INT(4)"`
	Splitnr       int       `json:"SplitNr" xorm:"not null pk INT(4)"`
	Actqty        float32   `json:"ActQty" xorm:"not null FLOAT(8)"`
	Goodqty       float32   `json:"GoodQty" xorm:"not null FLOAT(8)"`
	Scrapqty      float32   `json:"ScrapQty" xorm:"not null FLOAT(8)"`
	Reworkqty     float32   `json:"ReworkQty" xorm:"not null FLOAT(8)"`
	Quarantineqty float32   `json:"QuarantineQty" xorm:"not null FLOAT(8)"`
	Frozenqty     float32   `json:"FrozenQty" xorm:"not null FLOAT(8)"`
	Actqty1       float32   `json:"ActQty1" xorm:"not null FLOAT(8)"`
	Actqty2       float32   `json:"ActQty2" xorm:"not null FLOAT(8)"`
	Actqty3       float32   `json:"ActQty3" xorm:"not null FLOAT(8)"`
	Actqty4       float32   `json:"ActQty4" xorm:"not null FLOAT(8)"`
	Lastmodify    time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser      string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime    time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
}

/******数据表名******/
func (t *OmWooperationqty) TableName() string {
	return "OmWooperationqty"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperationqty) Add() error {
	e := db.Eloquent.Master()
	count := new(OmWooperationqty)
	/**主键：****/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperationqty) Del() (err error) {
	e := db.Eloquent.Master()
	/**主键：****/
	_, err = e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Delete(&OmWooperationqty{})
	if err != nil {
		return
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperationqty) Update() error {
	e := db.Eloquent.Master()
	/**主键：****/
	_, err := e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *OmWooperationqty) SelectOne() (OmWooperationqty, error) {
	e := db.Eloquent.Master()
	var data OmWooperationqty
	/**主键：****/
	_, err := e.ID(core.PK{t.Plantnr, t.Workorderid, t.Operationnr, t.Splitnr}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}
