// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type Skill struct {
	Plantnr    int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Skillnr    int       `json:"SkillNr" xorm:"not null pk INT(4)"`
	Abrev      string    `json:"Abrev" xorm:"not null NVARCHAR(80)"`
	Descr      string    `json:"Descr" xorm:"not null NVARCHAR(200)"`
	Skilltype  string    `json:"SkillType" xorm:"not null NVARCHAR(80)"`
	Ctrlpara1  int       `json:"CtrlPara1" xorm:"not null INT(4)"`
	Ctrlpara2  int       `json:"CtrlPara2" xorm:"not null INT(4)"`
	Ctrlstr1   string    `json:"CtrlStr1" xorm:"not null NVARCHAR(200)"`
	Ctrlstr2   string    `json:"CtrlStr2" xorm:"not null NVARCHAR(200)"`
	Lastmodify time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser   string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
}

/******数据表名******/
func (t *Skill) TableName() string {
	return "Skill"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Skill) Add() error {
	e := db.Eloquent.Master()
	count := new(Skill)
	/**主键：****/

	/******/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Skillnr}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Skill) Del() (err error) {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err = e.ID(core.PK{t.Plantnr, t.Skillnr}).Delete(&Skill{})
	if err != nil {
		return
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Skill) Update() error {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Skillnr}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Skill) SelectOne() (Skill, error) {
	e := db.Eloquent.Master()
	var data Skill
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Skillnr}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 查找所有的技能
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : LEO XUE
 *
 * @Date               : 2021/5/10 8:47
 *
 ******************************************************************************/
func (t *Skill) SelectAll() (datalst []Skill, err error) {
	e := db.Eloquent.Master()
	if err = e.Table(t.TableName()).Where("PlantNr = ?",t.Plantnr).OrderBy("SkillNr").Find(&datalst); err != nil{
		return
	}
	return
}
