// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type Tool struct {
	Plantnr                  int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Toolnr                   int       `json:"ToolNr" xorm:"not null pk INT(4)"`
	Toolgrpnr                int       `json:"ToolGrpNr" xorm:"not null INT(4)"`
	Descr                    string    `json:"Descr" xorm:"not null NVARCHAR(200)"`
	Projectid                string    `json:"ProjectId" xorm:"not null NVARCHAR(80)"`
	Status                   int       `json:"Status" xorm:"not null INT(4)"`
	Availqty                 int       `json:"AvailQty" xorm:"not null INT(4)"`
	Tooltypeid               string    `json:"ToolTypeId" xorm:"not null NVARCHAR(80)"`
	Alternativetoolnr        int       `json:"AlternativeToolNr" xorm:"not null INT(4)"`
	Frozentoggle             int       `json:"FrozenToggle" xorm:"not null BIT(1)"`
	Icon                     string    `json:"Icon" xorm:"not null NVARCHAR(200)"`
	Document                 string    `json:"Document" xorm:"not null NVARCHAR(200)"`
	Costrate                 float32   `json:"CostRate" xorm:"not null FLOAT(8)"`
	Costcenterid             string    `json:"CostCenterId" xorm:"not null NVARCHAR(80)"`
	Locationid               string    `json:"LocationId" xorm:"not null NVARCHAR(80)"`
	Manufacturer             string    `json:"Manufacturer" xorm:"not null NVARCHAR(200)"`
	Manufacturedate          time.Time `json:"ManufactureDate" xorm:"not null DATE(3)"`
	Maintenanceway           string    `json:"MaintenanceWay" xorm:"not null NVARCHAR(80)"`
	Lastmaintenancedate      time.Time `json:"LastMaintenanceDate" xorm:"not null DATE(3)"`
	Maintenancectrlvalue     int       `json:"MaintenanceCtrlValue" xorm:"not null INT(4)"`
	Lastmaintenancectrlvalue int       `json:"LastMaintenanceCtrlValue" xorm:"not null INT(4)"`
	Experationway            string    `json:"ExperationWay" xorm:"not null NVARCHAR(80)"`
	Experationdate           time.Time `json:"ExperationDate" xorm:"not null DATE(3)"`
	Experationctrlvalue      int       `json:"ExperationCtrlValue" xorm:"not null INT(4)"`
	Lastexperationctrlvalue  int       `json:"LastExperationCtrlValue" xorm:"not null INT(4)"`
	Lastmodify               time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser                 string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime               time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
}

/******数据表名******/
func (t *Tool) TableName() string {
	return "Tool"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Tool) Add() error {
	e := db.Eloquent.Master()
	count := new(Tool)
	/**主键：****/

	/******/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Toolnr}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Tool) Del() (err error) {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err = e.ID(core.PK{t.Plantnr, t.Toolnr}).Delete(&Tool{})
	if err != nil {
		return
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Tool) Update() error {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Toolnr}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *Tool) SelectOne() (Tool, error) {
	e := db.Eloquent.Master()
	var data Tool
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Toolnr}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 查找所有的工具
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : LEO XUE
 *
 * @Date               : 2021/5/10 8:47
 *
 ******************************************************************************/
func (t *Tool) SelectAll() (datalst []Tool, err error) {
	e := db.Eloquent.Master()
	if err = e.Table(t.TableName()).Where("PlantNr = ?",t.Plantnr).OrderBy("ToolNr").Find(&datalst); err != nil{
		return
	}
	return
}
