// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.
package models

import (
	"errors"
	"leit.com/aps_engine/db"
	"time"
	"xorm.io/core"
)

type WmsArttransitstock struct {
	Plantnr    int       `json:"PlantNr" xorm:"not null pk INT(4)"`
	Artid      string    `json:"ArtId" xorm:"not null pk NVARCHAR(80)"`
	Pos        int       `json:"Pos" xorm:"not null pk INT(4)"`
	Ordertime  time.Time `json:"OrderTime" xorm:"DATETIME(8)"`
	Actstock   float32   `json:"ActStock" xorm:"FLOAT(8)"`
	Lastmodify time.Time `json:"LastModify" xorm:"DATETIME(8)"`
	Lastuser   string    `json:"LastUser" xorm:"not null NVARCHAR(40)"`
	Createtime time.Time `json:"CreateTime" xorm:"DATETIME(8)"`
}

/******数据表名******/
func (t *WmsArttransitstock) TableName() string {
	return "WmsArttransitstock"
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据添加
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *WmsArttransitstock) Add() error {
	e := db.Eloquent.Master()
	count := new(WmsArttransitstock)
	/**主键：****/

	/******/
	affw, err := e.Table(t.TableName()).ID(core.PK{t.Plantnr, t.Artid, t.Pos}).Count(count)
	if err != nil {
		return err
	}
	if affw > 0 {
		return errors.New("数据已经存在！")
	}
	_, err = e.Table(t.TableName()).Insert(t)

	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据删除
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *WmsArttransitstock) Del() (err error) {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err = e.ID(core.PK{t.Plantnr, t.Artid, t.Pos}).Delete(&WmsArttransitstock{})
	if err != nil {
		return
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据修改
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *WmsArttransitstock) Update() error {
	e := db.Eloquent.Master()
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Artid, t.Pos}).Update(t)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 数据查找
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : Lou Wenzhi
 *
 * @Date               : 2021/3/6 8:47
 *
 ******************************************************************************/
func (t *WmsArttransitstock) SelectOne() (WmsArttransitstock, error) {
	e := db.Eloquent.Master()
	var data WmsArttransitstock
	/**主键：****/

	/******/
	_, err := e.ID(core.PK{t.Plantnr, t.Artid, t.Pos}).Get(&data)
	if err != nil {
		return data, err
	}
	return data, nil
}

/******************************************************************************
 *
 * @Function Name      :
 *-----------------------------------------------------------------------------
 *
 * @Description        : 查找所有的物料在途量
 *
 * @Function Parameters:
 *
 * @Return Value       :
 *
 * @Author             : LEO XUE
 *
 * @Date               : 2021/5/10 8:47
 *
 ******************************************************************************/
func (t *WmsArttransitstock) SelectAll() (datalst []WmsArttransitstock, err error) {
	e := db.Eloquent.Master()
	if err = e.Table(t.TableName()).Where("PlantNr = ?",t.Plantnr).Asc("ArtId", "OrderTime").Find(&datalst); err != nil{
		return
	}
	return
}
